@@ -1,7 +1,6 @@
-import scipy.stats as ss
+from statistics import quantiles
 from numpy import ndarray
 import numpy as np
-import math
 
 
 class QuantileHistogram:
@@ -12,14 +11,6 @@ class QuantileHistogram:
     ----------
     name : str
         The column name
-    ranks : ndarray
-        The column's ranked data
-    normalization : int
-        The number that normalizes the histogram values
-    quantiles : int
-        The number of quantiles
-    reference_hist : QuantileHistogram, optional
-        The reference histogram that provides the bucket boundaries
 
     Methods
     -------
@@ -70,14 +61,17 @@ class QuantileHistogram:
         self.name = name
         self.normalization_factor = normalization
         self.quantiles = n_quantiles
-        self.dist_matrix = self.calc_dist_matrix()
         if reference_hist is None:
-            self.add_buckets(ranks.min(initial=math.inf),
-                             ss.mstats.mquantiles(ranks, np.array(list(range(1, self.quantiles + 1))) / self.quantiles))
+            bucket = [round(q, 3) for q in quantiles(ranks, n=self.quantiles + 1, method='inclusive')] \
+                if len(ranks) > 1 else ranks
+
+            self.add_buckets(min(ranks), list(set(bucket)))
             self.add_values(ranks)
         else:
             self.bucket_boundaries = reference_hist.bucket_boundaries
             self.add_values(ranks)
+        self.n_buckets = len(self.bucket_boundaries)
+        self.dist_matrix = self.calc_dist_matrix()
 
     @property
     def get_values(self):
@@ -164,7 +158,7 @@ class QuantileHistogram:
             The bucket index that the value falls into or -1 if it does not fit in anyone
         """
         left = 0
-        right = self.quantiles - 1
+        right = len(self.bucket_boundaries) - 1
         while left <= right:
             mid = left + (right - left) // 2
             if self.bucket_boundaries[mid][0] <= x <= self.bucket_boundaries[mid][1]:
@@ -185,7 +179,7 @@ class QuantileHistogram:
         ndarray
             The distances between the buckets
         """
-        q = np.array(list(range(1, self.quantiles + 1))) / self.quantiles
+        q = np.array(list(range(1, self.n_buckets + 1))) / self.n_buckets
         dist = []
         for i in q:
             temp = []
